// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_SwingUtilities__
#define __javax_swing_SwingUtilities__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class SwingUtilities;
      class Icon;
      class JComponent;
      class JFrame;
      class JRootPane;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      class Component;
      class FontMetrics;
      class Font;
    }
  }
}

class javax::swing::SwingUtilities : public ::java::lang::Object
{
public:
  static ::java::awt::FontMetrics *getFontMetrics (::java::awt::Font *);
  static ::javax::swing::JRootPane *getRootPane (::java::awt::Component *);
  static void updateComponentTreeUI (::javax::swing::JFrame *) { }
  static ::java::lang::String *layoutCompoundLabel (::javax::swing::JComponent *, ::java::awt::FontMetrics *, ::java::lang::String *, ::javax::swing::Icon *, jint, jint, jint, jint, ::java::awt::Rectangle *, ::java::awt::Rectangle *, ::java::awt::Rectangle *, jint);
  SwingUtilities ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_SwingUtilities__ */
