// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_HTML__
#define __javax_swing_text_html_HTML__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          class HTML;
        }
      }
    }
  }
}

class javax::swing::text::html::HTML : public ::java::lang::Object
{
public:
  HTML ();

  friend class javax_swing_text_html_HTML$UnknownTag;
  friend class javax_swing_text_html_HTML$Tag;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_HTML__ */
