// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JScrollBar__
#define __javax_swing_JScrollBar__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JScrollBar;
    }
  }
}

class javax::swing::JScrollBar : public ::javax::swing::JComponent
{
public:
  JScrollBar ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JScrollBar__ */
