// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_table_JTableHeader__
#define __javax_swing_table_JTableHeader__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JTable;
      namespace table
      {
        class JTableHeader;
        class TableColumn;
        class TableColumnModel;
      }
    }
  }
}

class javax::swing::table::JTableHeader : public ::java::lang::Object
{
public:
  JTableHeader ();
private:
  static const jlong serialVersionUID = 5144633983372967710LL;
public:  // actually protected
  ::javax::swing::table::TableColumnModel * __attribute__((aligned(__alignof__( ::java::lang::Object )))) columnModel;
  ::javax::swing::table::TableColumn *draggedColumn;
  jint draggedDistance;
  jboolean reorderingAllowed;
  jboolean resizingAllowed;
  ::javax::swing::table::TableColumn *resizingColumn;
  ::javax::swing::JTable *table;
  jboolean updateTableInRealTime;

  friend class javax_swing_table_JTableHeader$AccessibleJTableHeader;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_table_JTableHeader__ */
