// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_DefaultCellRenderer__
#define __javax_swing_DefaultCellRenderer__

#pragma interface

#include <javax/swing/JLabel.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class DefaultCellRenderer;
      class JList;
    }
  }
}

class javax::swing::DefaultCellRenderer : public ::javax::swing::JLabel
{
public:
  virtual ::java::awt::Component *getListCellRendererComponent (::javax::swing::JList *, ::java::lang::Object *, jint, jboolean, jboolean);
  DefaultCellRenderer ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_DefaultCellRenderer__ */
