// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_MethodRef__
#define __gnu_gcj_runtime_MethodRef__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class MethodRef;
      }
      class RawData;
    }
  }
}

class gnu::gcj::runtime::MethodRef : public ::java::lang::Object
{
public: // actually package-private
  MethodRef (::gnu::gcj::RawData *, ::java::lang::Class *);
public:
  ::gnu::gcj::RawData * __attribute__((aligned(__alignof__( ::java::lang::Object )))) method;
  ::java::lang::Class *klass;

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_MethodRef__ */
