// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_gcj_runtime_VMClassLoader__
#define __gnu_gcj_runtime_VMClassLoader__

#pragma interface

#include <java/net/URLClassLoader.h>

extern "Java"
{
  namespace gnu
  {
    namespace gcj
    {
      namespace runtime
      {
        class VMClassLoader;
      }
    }
  }
}

class gnu::gcj::runtime::VMClassLoader : public ::java::net::URLClassLoader
{
private:
  VMClassLoader ();
  void init ();
public:  // actually protected
  ::java::lang::Class *findClass (::java::lang::String *);
public: // actually package-private
  static void initialize ();
private:
  ::java::util::HashSet * __attribute__((aligned(__alignof__( ::java::net::URLClassLoader )))) tried_libraries;
  jint lib_control;
public: // actually package-private
  static ::gnu::gcj::runtime::VMClassLoader *instance;
private:
  static const jint LIB_FULL = 0L;
  static const jint LIB_CACHE = 1L;
  static const jint LIB_NEVER = 2L;
  friend class ::java::lang::ClassLoader;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_gcj_runtime_VMClassLoader__ */
