// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_Tie__
#define __javax_rmi_CORBA_Tie__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      namespace CORBA
      {
        class Tie;
      }
      class ORB;
    }
  }
  namespace java
  {
    namespace rmi
    {
      class Remote;
    }
  }
}

class javax::rmi::CORBA::Tie : public ::java::lang::Object
{
public:
  virtual void deactivate () = 0;
  virtual ::java::rmi::Remote *getTarget () = 0;
  virtual ::javax::rmi::ORB *orb () = 0;
  virtual void orb (::javax::rmi::ORB *) = 0;
  virtual void setTarget (::java::rmi::Remote *) = 0;
  virtual ::java::lang::Object *thisObject () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_rmi_CORBA_Tie__ */
