// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_GapContent__
#define __javax_swing_text_GapContent__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace undo
      {
        class UndoableEdit;
      }
      namespace text
      {
        class GapContent;
        class Segment;
        class Position;
      }
    }
  }
}

class javax::swing::text::GapContent : public ::java::lang::Object
{
public:
  GapContent ();
  GapContent (jint);
  virtual ::javax::swing::text::Position *createPosition (jint);
  virtual jint length ();
  virtual ::javax::swing::undo::UndoableEdit *insertString (jint, ::java::lang::String *);
  virtual ::javax::swing::undo::UndoableEdit *remove (jint, jint);
  virtual ::java::lang::String *getString (jint, jint);
  virtual void getChars (jint, jint, ::javax::swing::text::Segment *);
public: // actually package-private
  ::java::lang::StringBuffer * __attribute__((aligned(__alignof__( ::java::lang::Object )))) buf;

  friend class javax_swing_text_GapContent$1;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_GapContent__ */
