// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_FileOutputStream__
#define __java_io_FileOutputStream__

#pragma interface

#include <java/io/OutputStream.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class FileChannel;
      }
    }
  }
}

class java::io::FileOutputStream : public ::java::io::OutputStream
{
public:
  FileOutputStream (::java::lang::String *, jboolean);
  FileOutputStream (::java::lang::String *);
  FileOutputStream (::java::io::File *);
  FileOutputStream (::java::io::File *, jboolean);
  FileOutputStream (::java::io::FileDescriptor *);
public:  // actually protected
  virtual void finalize () { }
public:
  ::java::io::FileDescriptor *getFD ();
  virtual void write (jint);
  virtual void write (jbyteArray);
  virtual void write (jbyteArray, jint, jint);
  virtual void close ();
  virtual ::java::nio::channels::FileChannel *getChannel ();
private:
  ::java::io::FileDescriptor * __attribute__((aligned(__alignof__( ::java::io::OutputStream )))) fd;
  ::java::nio::channels::FileChannel *ch;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_FileOutputStream__ */
