// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_DefaultListSelectionModel__
#define __javax_swing_DefaultListSelectionModel__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class DefaultListSelectionModel;
      namespace event
      {
        class ListSelectionListener;
      }
    }
  }
}

class javax::swing::DefaultListSelectionModel : public ::java::lang::Object
{
public: // actually package-private
  virtual ::java::util::Vector *get_listeners ();
public:
  virtual void addListSelectionListener (::javax::swing::event::ListSelectionListener *);
  virtual void removeListSelectionListener (::javax::swing::event::ListSelectionListener *);
  virtual jint getMinSelectionIndex ();
  virtual jint getMaxSelectionIndex ();
  virtual jboolean isSelectedIndex (jint);
  virtual jint getSelectionMode () { return mode; }
  virtual void setSelectionMode (jint);
public: // actually package-private
  virtual jboolean isSelectionEmpty ();
public:
  virtual void clearSelection ();
  virtual void setSelectionInterval (jint, jint);
  DefaultListSelectionModel ();
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  mode;
  ::java::util::Vector *sel;
  ::java::util::Vector *listeners;

  friend class javax_swing_DefaultListSelectionModel$Range;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_DefaultListSelectionModel__ */
