// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_io_FileNotFoundException__
#define __java_io_FileNotFoundException__

#pragma interface

#include <java/io/IOException.h>

class java::io::FileNotFoundException : public ::java::io::IOException
{
public:
  FileNotFoundException ();
  FileNotFoundException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -897856973823710492LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_io_FileNotFoundException__ */
