// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_event_SwingPropertyChangeSupport__
#define __javax_swing_event_SwingPropertyChangeSupport__

#pragma interface

#include <java/beans/PropertyChangeSupport.h>

extern "Java"
{
  namespace java
  {
    namespace beans
    {
      class PropertyChangeEvent;
      class PropertyChangeListener;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace event
      {
        class SwingPropertyChangeSupport;
        class EventListenerList;
      }
    }
  }
}

class javax::swing::event::SwingPropertyChangeSupport : public ::java::beans::PropertyChangeSupport
{
public:
  SwingPropertyChangeSupport (::java::lang::Object *);
private:
  void writeObject (::java::io::ObjectOutputStream *) { }
  void readObject (::java::io::ObjectInputStream *) { }
public:
  void addPropertyChangeListener (::java::beans::PropertyChangeListener *);
  void addPropertyChangeListener (::java::lang::String *, ::java::beans::PropertyChangeListener *);
  void removePropertyChangeListener (::java::beans::PropertyChangeListener *);
  void removePropertyChangeListener (::java::lang::String *, ::java::beans::PropertyChangeListener *);
  void firePropertyChange (::java::lang::String *, ::java::lang::Object *, ::java::lang::Object *);
  void firePropertyChange (::java::beans::PropertyChangeEvent *);
  jboolean hasListeners (::java::lang::String *);
private:
  static const jlong serialVersionUID = 7162625831330845068LL;
  ::javax::swing::event::EventListenerList * __attribute__((aligned(__alignof__( ::java::beans::PropertyChangeSupport )))) listeners;
  ::java::util::Hashtable *propertyListeners;
  ::java::lang::Object *source;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_event_SwingPropertyChangeSupport__ */
