// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_PrintGraphics__
#define __java_awt_PrintGraphics__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class PrintGraphics;
      class PrintJob;
    }
  }
}

class java::awt::PrintGraphics : public ::java::lang::Object
{
public:
  virtual ::java::awt::PrintJob *getPrintJob () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_PrintGraphics__ */
