( cd usr/bin ; rm -rf i486-slackware-linux-gcjh )
( cd usr/bin ; ln -sf gcjh i486-slackware-linux-gcjh )
( cd usr/bin ; rm -rf i486-slackware-linux-gcj )
( cd usr/bin ; ln -sf gcj i486-slackware-linux-gcj )
( cd usr/lib ; rm -rf libgcj.so )
( cd usr/lib ; ln -sf libgcj.so.5.0.0 libgcj.so )
( cd usr/lib ; rm -rf lib-org-w3c-dom.so )
( cd usr/lib ; ln -sf lib-org-w3c-dom.so.5.0.0 lib-org-w3c-dom.so )
( cd usr/lib ; rm -rf lib-org-xml-sax.so )
( cd usr/lib ; ln -sf lib-org-xml-sax.so.5.0.0 lib-org-xml-sax.so )
( cd usr/lib ; rm -rf libgcj.so.5 )
( cd usr/lib ; ln -sf libgcj.so.5.0.0 libgcj.so.5 )
( cd usr/lib ; rm -rf lib-org-xml-sax.so.5 )
( cd usr/lib ; ln -sf lib-org-xml-sax.so.5.0.0 lib-org-xml-sax.so.5 )
( cd usr/lib ; rm -rf lib-org-w3c-dom.so.5 )
( cd usr/lib ; ln -sf lib-org-w3c-dom.so.5.0.0 lib-org-w3c-dom.so.5 )
