// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_geom_Area__
#define __java_awt_geom_Area__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Rectangle;
      namespace geom
      {
        class PathIterator;
        class Point2D;
        class AffineTransform;
        class Rectangle2D;
        class Area;
      }
      class Shape;
    }
  }
}

class java::awt::geom::Area : public ::java::lang::Object
{
public:
  Area ();
  Area (::java::awt::Shape *);
  virtual void add (::java::awt::geom::Area *);
  virtual void subtract (::java::awt::geom::Area *);
  virtual void intersect (::java::awt::geom::Area *);
  virtual void exclusiveOr (::java::awt::geom::Area *);
  virtual void reset ();
  virtual jboolean isEmpty ();
  virtual jboolean isPolygonal ();
  virtual jboolean isRectangular ();
  virtual jboolean isSingular ();
  virtual ::java::awt::geom::Rectangle2D *getBounds2D ();
  virtual ::java::awt::Rectangle *getBounds ();
  virtual ::java::lang::Object *clone ();
  virtual jboolean equals (::java::awt::geom::Area *);
  virtual void transform (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::geom::Area *createTransformedArea (::java::awt::geom::AffineTransform *);
  virtual jboolean contains (jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Point2D *);
  virtual jboolean contains (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean contains (::java::awt::geom::Rectangle2D *);
  virtual jboolean intersects (jdouble, jdouble, jdouble, jdouble);
  virtual jboolean intersects (::java::awt::geom::Rectangle2D *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *);
  virtual ::java::awt::geom::PathIterator *getPathIterator (::java::awt::geom::AffineTransform *, jdouble);

  static ::java::lang::Class class$;
};

#endif /* __java_awt_geom_Area__ */
