// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_ObjectImpl__
#define __javax_rmi_CORBA_ObjectImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      namespace CORBA
      {
        class ObjectImpl;
      }
    }
  }
}

class javax::rmi::CORBA::ObjectImpl : public ::java::lang::Object
{
public:
  virtual ::javax::rmi::CORBA::ObjectImpl *_orb () { return 0; }
  virtual ::java::lang::String *object_to_string (::javax::rmi::CORBA::ObjectImpl *) { return 0; }
  ObjectImpl ();

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_CORBA_ObjectImpl__ */
