// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_Util__
#define __javax_rmi_CORBA_Util__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace rmi
    {
      class RemoteException;
      class Remote;
    }
  }
  namespace javax
  {
    namespace rmi
    {
      class ORB;
      namespace CORBA
      {
        class Util;
        class SystemException;
        class Stub;
        class Tie;
        class ValueHandler;
        class UtilDelegate;
      }
    }
  }
}

class javax::rmi::CORBA::Util : public ::java::lang::Object
{
private:
  Util ();
public:
  static ::java::lang::Object *copyObject (::java::lang::Object *, ::javax::rmi::ORB *);
  static JArray< ::java::lang::Object *> *copyObjects (JArray< ::java::lang::Object *> *, ::javax::rmi::ORB *);
  static ::javax::rmi::CORBA::ValueHandler *createValueHandler ();
  static ::java::lang::String *getCodebase (::java::lang::Class *);
  static ::javax::rmi::CORBA::Tie *getTie (::java::rmi::Remote *);
  static jboolean isLocal (::javax::rmi::CORBA::Stub *);
  static ::java::lang::Class *loadClass (::java::lang::String *, ::java::lang::String *, ::java::lang::ClassLoader *);
  static ::java::rmi::RemoteException *mapSystemException (::javax::rmi::CORBA::SystemException *);
  static ::java::lang::Object *readAny (::java::io::InputStream *);
  static void registerTarget (::javax::rmi::CORBA::Tie *, ::java::rmi::Remote *);
  static void unexportObject (::java::rmi::Remote *);
  static ::java::rmi::RemoteException *wrapException (::java::lang::Throwable *);
  static void writeAbstractObject (::java::io::OutputStream *, ::java::lang::Object *);
  static void writeAny (::java::io::OutputStream *, ::java::lang::Object *);
  static void writeRemoteObject (::java::io::OutputStream *, ::java::lang::Object *);
private:
  static ::javax::rmi::CORBA::UtilDelegate *delegate;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_CORBA_Util__ */
