// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_rmi_CORBA_StubDelegateImpl__
#define __gnu_javax_rmi_CORBA_StubDelegateImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace rmi
      {
        namespace CORBA
        {
          class StubDelegateImpl;
        }
      }
    }
  }
  namespace javax
  {
    namespace rmi
    {
      class ORB;
      namespace CORBA
      {
        class Stub;
      }
    }
  }
}

class gnu::javax::rmi::CORBA::StubDelegateImpl : public ::java::lang::Object
{
public:
  StubDelegateImpl ();
  virtual void connect (::javax::rmi::CORBA::Stub *, ::javax::rmi::ORB *);
  virtual jboolean equals (::javax::rmi::CORBA::Stub *, ::java::lang::Object *);
  virtual jint hashCode (::javax::rmi::CORBA::Stub *) { return hashCode__; }
  virtual ::java::lang::String *toString (::javax::rmi::CORBA::Stub *);
  virtual void readObject (::javax::rmi::CORBA::Stub *, ::java::io::ObjectInputStream *);
  virtual void writeObject (::javax::rmi::CORBA::Stub *, ::java::io::ObjectOutputStream *);
private:
  jint __attribute__((aligned(__alignof__( ::java::lang::Object ))))  hashCode__;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_rmi_CORBA_StubDelegateImpl__ */
