// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_nio_channels_Channel__
#define __java_nio_channels_Channel__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class Channel;
      }
    }
  }
}

class java::nio::channels::Channel : public ::java::lang::Object
{
public:
  virtual jboolean isOpen () = 0;
  virtual void close () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_nio_channels_Channel__ */
