// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_SystemException__
#define __javax_rmi_CORBA_SystemException__

#pragma interface

#include <java/lang/Exception.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      namespace CORBA
      {
        class SystemException;
      }
    }
  }
}

class javax::rmi::CORBA::SystemException : public ::java::lang::Exception
{
public:
  SystemException ();

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_CORBA_SystemException__ */
