// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicIconFactory__
#define __javax_swing_plaf_basic_BasicIconFactory__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicIconFactory;
        }
      }
      class Icon;
    }
  }
}

class javax::swing::plaf::basic::BasicIconFactory : public ::java::lang::Object
{
public:
  BasicIconFactory ();
  static ::javax::swing::Icon *getMenuItemCheckIcon () { return 0; }
  static ::javax::swing::Icon *getMenuItemArrowIcon () { return 0; }
  static ::javax::swing::Icon *getMenuArrowIcon () { return 0; }
  static ::javax::swing::Icon *getCheckBoxIcon () { return 0; }
  static ::javax::swing::Icon *getRadioButtonIcon () { return 0; }
  static ::javax::swing::Icon *getCheckBoxMenuItemIcon () { return 0; }
  static ::javax::swing::Icon *getRadioButtonMenuItemIcon () { return 0; }
  static ::javax::swing::Icon *createEmptyFrameIcon () { return 0; }
public: // actually package-private
  static const jlong serialVersionUID = 5605588811185324383LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicIconFactory__ */
