// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_View__
#define __javax_swing_text_View__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Shape;
      class Graphics;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class Document;
        class View;
        class Element;
      }
    }
  }
}

class javax::swing::text::View : public ::java::lang::Object
{
public:
  View (::javax::swing::text::Element *);
  virtual jint getViewCount ();
  virtual ::javax::swing::text::View *getView (jint);
  virtual void remove (jint);
  virtual void insert (jint, ::javax::swing::text::View *);
  virtual void append (::javax::swing::text::View *);
  virtual void paint (::java::awt::Graphics *, ::java::awt::Shape *);
  virtual void setParent (::javax::swing::text::View *);
  virtual ::javax::swing::text::View *getParent () { return parent; }
  virtual void setSize (jint, jint);
  virtual ::javax::swing::text::Document *getDocument ();
  virtual ::javax::swing::text::Element *getElement () { return elt; }
  virtual jfloat getPreferredSpan (jint);
public: // actually package-private
  static jint BadBreakWeight;
  static jint ExcellentBreakWeight;
  static jint ForcedBreakWeight;
  static jint GoodBreakWeight;
public:
  static const jint X_AXIS = 0L;
  static const jint Y_AXIS = 1L;
public: // actually package-private
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Object ))))  width;
  jfloat height;
  ::javax::swing::text::Element *elt;
  ::javax::swing::text::View *parent;
  ::java::util::Vector *v;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_View__ */
