// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_ClassDesc__
#define __javax_rmi_CORBA_ClassDesc__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      namespace CORBA
      {
        class ClassDesc;
      }
    }
  }
}

class javax::rmi::CORBA::ClassDesc : public ::java::lang::Object
{
public:
  ClassDesc ();
private:
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) repid;
  ::java::lang::String *codebase;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_CORBA_ClassDesc__ */
