// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_Box__
#define __javax_swing_Box__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class Box;
    }
  }
}

class javax::swing::Box : public ::javax::swing::JComponent
{
public: // actually package-private
  Box (jint);
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_Box__ */
