// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_ORB__
#define __javax_rmi_ORB__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      class ORB;
    }
  }
}

class javax::rmi::ORB : public ::java::lang::Object
{
public:
  ORB ();

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_ORB__ */
