// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_awt_ClasspathToolkit__
#define __gnu_java_awt_ClasspathToolkit__

#pragma interface

#include <java/awt/Toolkit.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace awt
      {
        class ClasspathToolkit;
        namespace peer
        {
          class ClasspathFontPeer;
        }
      }
    }
  }
  namespace java
  {
    namespace net
    {
      class URL;
    }
    namespace awt
    {
      class Image;
      class FontMetrics;
      class Font;
      namespace image
      {
        class ColorModel;
      }
      class Dimension;
      class GraphicsEnvironment;
    }
  }
}

class gnu::java::awt::ClasspathToolkit : public ::java::awt::Toolkit
{
public:
  virtual ::java::awt::GraphicsEnvironment *getLocalGraphicsEnvironment () = 0;
  virtual ::java::awt::Dimension *getScreenSize ();
  virtual ::java::awt::image::ColorModel *getColorModel ();
  virtual ::java::awt::FontMetrics *getFontMetrics (::java::awt::Font *);
  virtual ::gnu::java::awt::peer::ClasspathFontPeer *getClasspathFontPeer (::java::lang::String *, ::java::util::Map *) = 0;
  virtual ::java::awt::Font *getFont (::java::lang::String *, ::java::util::Map *);
  virtual ::java::awt::Font *createFont (jint, ::java::io::InputStream *) = 0;
  virtual ::java::awt::Image *getImage (::java::lang::String *);
  virtual ::java::awt::Image *getImage (::java::net::URL *);
  virtual ::java::awt::Image *createImage (::java::lang::String *);
  ClasspathToolkit ();
private:
  ::java::util::Map * __attribute__((aligned(__alignof__( ::java::awt::Toolkit )))) imageCache;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_awt_ClasspathToolkit__ */
