// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JScrollPane__
#define __javax_swing_JScrollPane__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
  namespace javax
  {
    namespace swing
    {
      class JScrollPane;
      class JScrollBar;
      class JViewport;
    }
  }
}

class javax::swing::JScrollPane : public ::javax::swing::JComponent
{
public:
  JScrollPane ();
  JScrollPane (::java::awt::Component *);
  JScrollPane (jint, jint);
  JScrollPane (::java::awt::Component *, jint, jint);
  virtual ::java::lang::String *getUIClassID ();
  virtual ::javax::swing::JViewport *getViewport () { return viewport; }
  virtual ::javax::swing::JViewport *createViewport ();
  virtual void setViewport (::javax::swing::JViewport *);
  virtual void updateUI ();
  virtual void setViewportView (::java::awt::Component *);
public:  // actually protected
  ::javax::swing::JViewport * __attribute__((aligned(__alignof__( ::javax::swing::JComponent )))) columnHeader;
  ::javax::swing::JViewport *rowHeader;
  ::java::awt::Component *lowerLeft;
  ::java::awt::Component *lowerRight;
  ::java::awt::Component *upperLeft;
  ::java::awt::Component *upperRight;
  ::javax::swing::JScrollBar *horizontalScrollBar;
  jint horizontalScrollBarPolicy;
  ::javax::swing::JScrollBar *verticalScrollBar;
  jint verticalScrollBarPolicy;
  ::javax::swing::JViewport *viewport;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JScrollPane__ */
