// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_peer_ListPeer__
#define __java_awt_peer_ListPeer__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace peer
      {
        class ListPeer;
      }
      class Dimension;
    }
  }
}

class java::awt::peer::ListPeer : public ::java::lang::Object
{
public:
  virtual void add (::java::lang::String *, jint) = 0;
  virtual void addItem (::java::lang::String *, jint) = 0;
  virtual void clear () = 0;
  virtual void delItems (jint, jint) = 0;
  virtual void deselect (jint) = 0;
  virtual jintArray getSelectedIndexes () = 0;
  virtual void makeVisible (jint) = 0;
  virtual ::java::awt::Dimension *minimumSize (jint) = 0;
  virtual ::java::awt::Dimension *preferredSize (jint) = 0;
  virtual void removeAll () = 0;
  virtual void select (jint) = 0;
  virtual void setMultipleMode (jboolean) = 0;
  virtual void setMultipleSelections (jboolean) = 0;
  virtual ::java::awt::Dimension *getPreferredSize (jint) = 0;
  virtual ::java::awt::Dimension *getMinimumSize (jint) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_peer_ListPeer__ */
