// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_provider_DSAParameterGenerator__
#define __gnu_java_security_provider_DSAParameterGenerator__

#pragma interface

#include <java/security/AlgorithmParameterGeneratorSpi.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace provider
        {
          class DSAParameterGenerator;
        }
      }
    }
  }
  namespace java
  {
    namespace security
    {
      class AlgorithmParameters;
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
    }
  }
}

class gnu::java::security::provider::DSAParameterGenerator : public ::java::security::AlgorithmParameterGeneratorSpi
{
public:
  DSAParameterGenerator ();
  virtual void engineInit (jint, ::java::security::SecureRandom *);
  virtual void engineInit (::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);
  virtual ::java::security::AlgorithmParameters *engineGenerateParameters ();
private:
  jint __attribute__((aligned(__alignof__( ::java::security::AlgorithmParameterGeneratorSpi ))))  size;
  ::java::security::SecureRandom *random;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_provider_DSAParameterGenerator__ */
