// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JTabbedPane__
#define __javax_swing_JTabbedPane__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace accessibility
    {
      class AccessibleContext;
    }
    namespace swing
    {
      class JTabbedPane;
      namespace plaf
      {
        class TabbedPaneUI;
      }
      class Icon;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
}

class javax::swing::JTabbedPane : public ::javax::swing::JComponent
{
public:
  JTabbedPane ();
  virtual void addTab (::java::lang::String *, ::java::awt::Component *);
  virtual void addTab (::java::lang::String *, ::javax::swing::Icon *, ::java::awt::Component *);
  virtual void addTab (::java::lang::String *, ::javax::swing::Icon *, ::java::awt::Component *, ::java::lang::String *);
  virtual jint getTabCount ();
  virtual ::java::awt::Component *getComponentAt (jint);
  virtual ::java::lang::String *getUIClassID ();
  virtual void setUI (::javax::swing::plaf::TabbedPaneUI *);
  virtual ::javax::swing::plaf::TabbedPaneUI *getUI ();
  virtual void updateUI ();
  virtual ::javax::accessibility::AccessibleContext *getAccessibleContext () { return 0; }
public:  // actually protected
  virtual ::java::lang::String *paramString ();
private:
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::javax::swing::JComponent )))) tabs;

  friend class javax_swing_JTabbedPane$Tab;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JTabbedPane__ */
