// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JInternalFrame__
#define __javax_swing_JInternalFrame__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JInternalFrame;
    }
  }
}

class javax::swing::JInternalFrame : public ::javax::swing::JComponent
{
public:
  JInternalFrame ();
private:
  static const jlong serialVersionUID = -5425177187760785402LL;
public:
  static ::java::lang::String *CONTENT_PANE_PROPERTY;
  static ::java::lang::String *MENU_BAR_PROPERTY;
  static ::java::lang::String *TITLE_PROPERTY;
  static ::java::lang::String *LAYERED_PANE_PROPERTY;
  static ::java::lang::String *ROOT_PANE_PROPERTY;
  static ::java::lang::String *GLASS_PANE_PROPERTY;
  static ::java::lang::String *FRAME_ICON_PROPERTY;
  static ::java::lang::String *IS_SELECTED_PROPERTY;
  static ::java::lang::String *IS_CLOSED_PROPERTY;
  static ::java::lang::String *IS_MAXIMUM_PROPERTY;
  static ::java::lang::String *IS_ICON_PROPERTY;

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JInternalFrame__ */
