// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_Key__
#define __java_security_Key__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      class Key;
    }
  }
}

class java::security::Key : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getAlgorithm () = 0;
  virtual ::java::lang::String *getFormat () = 0;
  virtual jbyteArray getEncoded () = 0;
  static const jlong serialVersionUID = 6603384152749567654LL;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_security_Key__ */
