// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JRootPane__
#define __javax_swing_JRootPane__

#pragma interface

#include <javax/swing/JComponent.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JRootPane;
      class JComponent;
      class JMenuBar;
      class JLayeredPane;
    }
  }
  namespace java
  {
    namespace awt
    {
      class LayoutManager;
      class Container;
      class Component;
    }
  }
}

class javax::swing::JRootPane : public ::javax::swing::JComponent
{
public:
  virtual ::java::lang::String *getUIClassID ();
public: // actually package-private
  virtual void setJMenuBar (::javax::swing::JMenuBar *);
  virtual ::javax::swing::JMenuBar *getJMenuBar () { return menuBar; }
public:
  virtual ::java::awt::Container *getContentPane ();
  virtual void setContentPane (::java::awt::Container *);
public:  // actually protected
  virtual void addImpl (::java::awt::Component *, ::java::lang::Object *, jint);
public:
  virtual ::java::awt::Component *getGlassPane ();
  virtual void setGlassPane (::java::awt::Component *);
  virtual ::javax::swing::JLayeredPane *getLayeredPane ();
  virtual void setLayeredPane (::javax::swing::JLayeredPane *);
public: // actually package-private
  JRootPane ();
public:  // actually protected
  virtual ::java::awt::LayoutManager *createRootLayout ();
public: // actually package-private
  virtual ::javax::swing::JComponent *createContentPane ();
  virtual ::java::awt::Component *createGlassPane ();
  virtual ::javax::swing::JLayeredPane *createLayeredPane ();
public:  // actually protected
  ::java::awt::Component * __attribute__((aligned(__alignof__( ::javax::swing::JComponent )))) glassPane;
  ::javax::swing::JLayeredPane *layeredPane;
  ::javax::swing::JMenuBar *menuBar;
  ::java::awt::Container *contentPane;

  friend class javax_swing_JRootPane$RootLayout;
  friend class javax_swing_JRootPane$AccessibleJRootPane;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JRootPane__ */
