// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NoSuchMethodException__
#define __java_lang_NoSuchMethodException__

#pragma interface

#include <java/lang/Exception.h>

class java::lang::NoSuchMethodException : public ::java::lang::Exception
{
public:
  NoSuchMethodException ();
  NoSuchMethodException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 5034388446362600923LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NoSuchMethodException__ */
