// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_ImageIcon__
#define __javax_swing_ImageIcon__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class ImageIcon;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Graphics;
      class Component;
      class Image;
    }
  }
}

class javax::swing::ImageIcon : public ::java::lang::Object
{
public:
  ImageIcon (::java::lang::String *);
  ImageIcon (::java::lang::String *, ::java::lang::String *);
  virtual void setParent (::java::awt::Component *);
  virtual ::java::awt::Image *getImage () { return image; }
  virtual ::java::lang::String *getDescription () { return descr; }
  virtual void setDescription (::java::lang::String *);
  virtual jint getIconHeight ();
  virtual jint getIconWidth ();
  virtual void paintIcon (::java::awt::Component *, ::java::awt::Graphics *, jint, jint);
public: // actually package-private
  ::java::awt::Image * __attribute__((aligned(__alignof__( ::java::lang::Object )))) image;
  ::java::lang::String *file;
  ::java::lang::String *descr;
  ::java::awt::Component *observer;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_ImageIcon__ */
