// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_rmi_CORBA_ValueHandlerImpl__
#define __gnu_javax_rmi_CORBA_ValueHandlerImpl__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace rmi
      {
        namespace CORBA
        {
          class ValueHandlerImpl;
        }
      }
    }
  }
}

class gnu::javax::rmi::CORBA::ValueHandlerImpl : public ::java::lang::Object
{
public:
  virtual ::java::lang::String *getRMIRepositoryID (::java::lang::Class *);
  virtual ::java::lang::Runtime *getRunTimeCodeBase ();
  virtual jboolean isCustomMarshaled (::java::lang::Class *);
  virtual ::java::io::Serializable *readValue (::java::io::InputStream *, jint, ::java::lang::Class *, ::java::lang::String *, ::java::lang::Runtime *);
  virtual ::java::io::Serializable *writeReplace (::java::io::Serializable *);
  virtual void writeValue (::java::io::OutputStream *, ::java::io::Serializable *);
  ValueHandlerImpl ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_rmi_CORBA_ValueHandlerImpl__ */
