// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_net_Inet6Address__
#define __java_net_Inet6Address__

#pragma interface

#include <java/net/InetAddress.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace net
    {
      class Inet6Address;
    }
  }
}

class java::net::Inet6Address : public ::java::net::InetAddress
{
public: // actually package-private
  Inet6Address (jbyteArray, ::java::lang::String *);
public:
  jboolean isMulticastAddress ();
  jboolean isAnyLocalAddress ();
  jboolean isLoopbackAddress ();
  jboolean isLinkLocalAddress ();
  jboolean isSiteLocalAddress ();
  jboolean isMCGlobal ();
  jboolean isMCNodeLocal ();
  jboolean isMCLinkLocal ();
  jboolean isMCSiteLocal ();
  jboolean isMCOrgLocal ();
  jbyteArray getAddress () { return ipaddress; }
  ::java::lang::String *getHostAddress ();
  jint hashCode ();
  jboolean equals (::java::lang::Object *);
  jboolean isIPv4CompatibleAddress ();
public: // actually package-private
  static const jlong serialVersionUID = 6880410070516793377LL;
  jbyteArray __attribute__((aligned(__alignof__( ::java::net::InetAddress ))))  ipaddress;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_net_Inet6Address__ */
