// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_zip_ZipException__
#define __java_util_zip_ZipException__

#pragma interface

#include <java/io/IOException.h>

class java::util::zip::ZipException : public ::java::io::IOException
{
public:
  ZipException ();
  ZipException (::java::lang::String *);
private:
  static const jlong serialVersionUID = 8000196834066748623LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_zip_ZipException__ */
