// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_Renderer__
#define __javax_swing_Renderer__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class Renderer;
    }
  }
  namespace java
  {
    namespace awt
    {
      class Component;
    }
  }
}

class javax::swing::Renderer : public ::java::lang::Object
{
public:
  virtual void setValue (::java::lang::Object *, jboolean) = 0;
  virtual ::java::awt::Component *getComponent () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_swing_Renderer__ */
