// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_basic_BasicTextUI__
#define __javax_swing_plaf_basic_BasicTextUI__

#pragma interface

#include <javax/swing/plaf/TextUI.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class Point;
      class Rectangle;
      class Graphics;
      class Dimension;
      class Color;
    }
  }
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace basic
        {
          class BasicTextUI;
        }
        class ComponentUI;
      }
      class JComponent;
      namespace text
      {
        class Element;
        class Position$Bias;
        class JTextComponent;
        class EditorKit;
        class View;
      }
    }
  }
}

class javax::swing::plaf::basic::BasicTextUI : public ::javax::swing::plaf::TextUI
{
public:
  BasicTextUI ();
  static ::javax::swing::plaf::ComponentUI *createUI (::javax::swing::JComponent *);
  virtual void installUI (::javax::swing::JComponent *);
  virtual ::java::awt::Dimension *getPreferredSize (::javax::swing::JComponent *);
  virtual void paint (::java::awt::Graphics *, ::javax::swing::JComponent *) { }
  virtual void damageRange (::javax::swing::text::JTextComponent *, jint, jint);
  virtual void damageRange (::javax::swing::text::JTextComponent *, jint, jint, ::javax::swing::text::Position$Bias *, ::javax::swing::text::Position$Bias *) { }
  virtual ::javax::swing::text::EditorKit *getEditorKit (::javax::swing::text::JTextComponent *) { return kit; }
  virtual jint getNextVisualPositionFrom (::javax::swing::text::JTextComponent *, jint, ::javax::swing::text::Position$Bias *, jint, JArray< ::javax::swing::text::Position$Bias *> *);
  virtual ::javax::swing::text::View *getRootView (::javax::swing::text::JTextComponent *) { return view; }
  virtual ::java::awt::Rectangle *modelToView (::javax::swing::text::JTextComponent *, jint);
  virtual ::java::awt::Rectangle *modelToView (::javax::swing::text::JTextComponent *, jint, ::javax::swing::text::Position$Bias *) { return 0; }
  virtual jint viewToModel (::javax::swing::text::JTextComponent *, ::java::awt::Point *);
  virtual jint viewToModel (::javax::swing::text::JTextComponent *, ::java::awt::Point *, JArray< ::javax::swing::text::Position$Bias *> *);
  virtual ::javax::swing::text::View *create (::javax::swing::text::Element *) { return 0; }
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::javax::swing::plaf::TextUI ))))  gap;
  ::javax::swing::text::View *view;
  ::java::awt::Color *textColor;
  ::java::awt::Color *disabledTextColor;
  ::java::awt::Color *normalBackgroundColor;
  ::javax::swing::text::EditorKit *kit;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_basic_BasicTextUI__ */
