// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_dnd_DropTargetListener__
#define __java_awt_dnd_DropTargetListener__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace dnd
      {
        class DropTargetListener;
        class DropTargetDropEvent;
        class DropTargetEvent;
        class DropTargetDragEvent;
      }
    }
  }
}

class java::awt::dnd::DropTargetListener : public ::java::lang::Object
{
public:
  virtual void dragEnter (::java::awt::dnd::DropTargetDragEvent *) = 0;
  virtual void dragOver (::java::awt::dnd::DropTargetDragEvent *) = 0;
  virtual void dropActionChanged (::java::awt::dnd::DropTargetDragEvent *) = 0;
  virtual void dragExit (::java::awt::dnd::DropTargetEvent *) = 0;
  virtual void drop (::java::awt::dnd::DropTargetDropEvent *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_awt_dnd_DropTargetListener__ */
