// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_nio_FileLockImpl__
#define __gnu_java_nio_FileLockImpl__

#pragma interface

#include <java/nio/channels/FileLock.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace nio
      {
        class FileLockImpl;
      }
    }
  }
  namespace java
  {
    namespace nio
    {
      namespace channels
      {
        class FileChannel;
      }
    }
  }
}

class gnu::java::nio::FileLockImpl : public ::java::nio::channels::FileLock
{
public:
  FileLockImpl (::java::io::FileDescriptor *, ::java::nio::channels::FileChannel *, jlong, jlong, jboolean);
  virtual jboolean isValid ();
private:
  void releaseImpl ();
public:
  virtual void release ();
private:
  ::java::io::FileDescriptor * __attribute__((aligned(__alignof__( ::java::nio::channels::FileLock )))) fd;
  jboolean released;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_nio_FileLockImpl__ */
