// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_PlainDocument__
#define __javax_swing_text_PlainDocument__

#pragma interface

#include <javax/swing/text/AbstractDocument.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        class PlainDocument;
        class Element;
      }
    }
  }
}

class javax::swing::text::PlainDocument : public ::javax::swing::text::AbstractDocument
{
public: // actually package-private
  PlainDocument ();
public:
  virtual ::javax::swing::text::Element *getDefaultRootElement () { return 0; }
  virtual ::javax::swing::text::Element *getParagraphElement (jint) { return 0; }

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_PlainDocument__ */
