// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_html_parser_ParserDelegator__
#define __javax_swing_text_html_parser_ParserDelegator__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace text
      {
        namespace html
        {
          namespace parser
          {
            class ParserDelegator;
          }
        }
      }
    }
  }
}

class javax::swing::text::html::parser::ParserDelegator : public ::java::lang::Object
{
public:
  ParserDelegator ();

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_html_parser_ParserDelegator__ */
