// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_javax_rmi_CORBA_UtilDelegateImpl__
#define __gnu_javax_rmi_CORBA_UtilDelegateImpl__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace javax
    {
      namespace rmi
      {
        namespace CORBA
        {
          class UtilDelegateImpl;
        }
      }
    }
  }
  namespace java
  {
    namespace rmi
    {
      class RemoteException;
      class Remote;
    }
  }
  namespace javax
  {
    namespace rmi
    {
      namespace CORBA
      {
        class SystemException;
        class Stub;
        class Tie;
        class ValueHandler;
      }
      class ORB;
    }
  }
}

class gnu::javax::rmi::CORBA::UtilDelegateImpl : public ::java::lang::Object
{
public:
  virtual ::java::lang::Object *copyObject (::java::lang::Object *, ::javax::rmi::ORB *);
  virtual JArray< ::java::lang::Object *> *copyObjects (JArray< ::java::lang::Object *> *, ::javax::rmi::ORB *);
  virtual ::javax::rmi::CORBA::ValueHandler *createValueHandler ();
  virtual ::java::lang::String *getCodebase (::java::lang::Class *);
  virtual ::javax::rmi::CORBA::Tie *getTie (::java::rmi::Remote *);
  virtual jboolean isLocal (::javax::rmi::CORBA::Stub *);
  virtual ::java::lang::Class *loadClass (::java::lang::String *, ::java::lang::String *, ::java::lang::ClassLoader *);
  virtual ::java::rmi::RemoteException *mapSystemException (::javax::rmi::CORBA::SystemException *);
  virtual ::java::lang::Object *readAny (::java::io::InputStream *);
  virtual void registerTarget (::javax::rmi::CORBA::Tie *, ::java::rmi::Remote *);
  virtual void unexportObject (::java::rmi::Remote *);
  virtual ::java::rmi::RemoteException *wrapException (::java::lang::Throwable *);
  virtual void writeAbstractObject (::java::io::OutputStream *, ::java::lang::Object *);
  virtual void writeAny (::java::io::OutputStream *, ::java::lang::Object *);
  virtual void writeRemoteObject (::java::io::OutputStream *, ::java::lang::Object *);
  UtilDelegateImpl ();

  static ::java::lang::Class class$;
};

#endif /* __gnu_javax_rmi_CORBA_UtilDelegateImpl__ */
