// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_StubDelegate__
#define __javax_rmi_CORBA_StubDelegate__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      class ORB;
      namespace CORBA
      {
        class StubDelegate;
        class Stub;
      }
    }
  }
}

class javax::rmi::CORBA::StubDelegate : public ::java::lang::Object
{
public:
  virtual void connect (::javax::rmi::CORBA::Stub *, ::javax::rmi::ORB *) = 0;
  virtual jboolean equals (::javax::rmi::CORBA::Stub *, ::java::lang::Object *) = 0;
  virtual jint hashCode (::javax::rmi::CORBA::Stub *) = 0;
  virtual void readObject (::javax::rmi::CORBA::Stub *, ::java::io::ObjectInputStream *) = 0;
  virtual ::java::lang::String *toString (::javax::rmi::CORBA::Stub *) = 0;
  virtual void writeObject (::javax::rmi::CORBA::Stub *, ::java::io::ObjectOutputStream *) = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __javax_rmi_CORBA_StubDelegate__ */
