// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_JTextField__
#define __javax_swing_JTextField__

#pragma interface

#include <javax/swing/JEditorPane.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class JTextField;
    }
  }
  namespace java
  {
    namespace awt
    {
      namespace event
      {
        class ActionListener;
      }
    }
  }
}

class javax::swing::JTextField : public ::javax::swing::JEditorPane
{
public:
  JTextField ();
  JTextField (jint);
  virtual void addActionListener (::java::awt::event::ActionListener *);
  virtual void removeActionListener (::java::awt::event::ActionListener *);
  virtual void selectAll () { }
public: // actually package-private
  ::java::util::Vector * __attribute__((aligned(__alignof__( ::javax::swing::JEditorPane )))) actions;

  friend class javax_swing_JTextField$AccessibleJTextField;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_JTextField__ */
