// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_IllegalComponentStateException__
#define __java_awt_IllegalComponentStateException__

#pragma interface

#include <java/lang/IllegalStateException.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      class IllegalComponentStateException;
    }
  }
}

class java::awt::IllegalComponentStateException : public ::java::lang::IllegalStateException
{
public:
  IllegalComponentStateException ();
  IllegalComponentStateException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -1889339587208144238LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_IllegalComponentStateException__ */
