// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_Certificate__
#define __java_security_cert_Certificate__

#pragma interface

#include <java/lang/Object.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class Certificate;
      }
      class PublicKey;
    }
  }
}

class java::security::cert::Certificate : public ::java::lang::Object
{
public:  // actually protected
  Certificate (::java::lang::String *);
public:
  ::java::lang::String *getType () { return type; }
  virtual jboolean equals (::java::lang::Object *);
  virtual jint hashCode ();
  virtual jbyteArray getEncoded () = 0;
  virtual void verify (::java::security::PublicKey *) = 0;
  virtual void verify (::java::security::PublicKey *, ::java::lang::String *) = 0;
  virtual ::java::lang::String *toString () = 0;
  virtual ::java::security::PublicKey *getPublicKey () = 0;
public:  // actually protected
  virtual ::java::lang::Object *writeReplace ();
private:
  static const jlong serialVersionUID = -6751606818319535583LL;
  ::java::lang::String * __attribute__((aligned(__alignof__( ::java::lang::Object )))) type;

  friend class java_security_cert_Certificate$CertificateRep;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_cert_Certificate__ */
