// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_cert_PolicyNode__
#define __java_security_cert_PolicyNode__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace cert
      {
        class PolicyNode;
      }
    }
  }
}

class java::security::cert::PolicyNode : public ::java::lang::Object
{
public:
  virtual ::java::util::Iterator *getChildren () = 0;
  virtual jint getDepth () = 0;
  virtual ::java::util::Set *getExpectedPolicies () = 0;
  virtual ::java::security::cert::PolicyNode *getParent () = 0;
  virtual ::java::util::Set *getPolicyQualifiers () = 0;
  virtual ::java::lang::String *getValidPolicy () = 0;
  virtual jboolean isCritical () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_security_cert_PolicyNode__ */
