// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_beans_EmptyBeanInfo__
#define __gnu_java_beans_EmptyBeanInfo__

#pragma interface

#include <gnu/java/beans/ExplicitBeanInfo.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace beans
      {
        class EmptyBeanInfo;
      }
    }
  }
}

class gnu::java::beans::EmptyBeanInfo : public ::gnu::java::beans::ExplicitBeanInfo
{
public:
  EmptyBeanInfo (::java::lang::Class *);

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_beans_EmptyBeanInfo__ */
