// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_text_PlainEditorKit__
#define __javax_swing_text_PlainEditorKit__

#pragma interface

#include <javax/swing/text/EditorKit.h>
#include <gcj/array.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class Action;
      class JEditorPane;
      namespace text
      {
        class ViewFactory;
        class Document;
        class Caret;
        class PlainEditorKit;
      }
    }
  }
}

class javax::swing::text::PlainEditorKit : public ::javax::swing::text::EditorKit
{
public:
  PlainEditorKit ();
  PlainEditorKit (::javax::swing::text::PlainEditorKit *);
public:  // actually protected
  virtual ::java::lang::Object *clone ();
public: // actually package-private
  virtual void deinstall (::javax::swing::JEditorPane *) { }
  virtual void install (::javax::swing::JEditorPane *) { }
  virtual ::javax::swing::text::Caret *createCaret () { return 0; }
  virtual ::javax::swing::text::Document *createDefaultDocument () { return 0; }
  virtual JArray< ::javax::swing::Action *> *getActions () { return 0; }
  virtual ::java::lang::String *getContentType () { return 0; }
  virtual ::javax::swing::text::ViewFactory *getViewFactory () { return 0; }
  virtual void read (::java::io::InputStream *, ::javax::swing::text::Document *, jint) { }
  virtual void read (::java::io::Reader *, ::javax::swing::text::Document *, jint) { }
  virtual void write (::java::io::OutputStream *, ::javax::swing::text::Document *, jint, jint) { }
  virtual void write (::java::io::Writer *, ::javax::swing::text::Document *, jint, jint) { }
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_text_PlainEditorKit__ */
