// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_spec_RSAOtherPrimeInfo__
#define __java_security_spec_RSAOtherPrimeInfo__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace spec
      {
        class RSAOtherPrimeInfo;
      }
    }
    namespace math
    {
      class BigInteger;
    }
  }
}

class java::security::spec::RSAOtherPrimeInfo : public ::java::lang::Object
{
public:
  RSAOtherPrimeInfo (::java::math::BigInteger *, ::java::math::BigInteger *, ::java::math::BigInteger *);
  ::java::math::BigInteger *getPrime () { return prime; }
  ::java::math::BigInteger *getExponent () { return primeExponent; }
  ::java::math::BigInteger *getCrtCoefficient () { return crtCoefficient; }
private:
  ::java::math::BigInteger * __attribute__((aligned(__alignof__( ::java::lang::Object )))) prime;
  ::java::math::BigInteger *primeExponent;
  ::java::math::BigInteger *crtCoefficient;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_security_spec_RSAOtherPrimeInfo__ */
