// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_NumberFormatException__
#define __java_lang_NumberFormatException__

#pragma interface

#include <java/lang/IllegalArgumentException.h>

class java::lang::NumberFormatException : public ::java::lang::IllegalArgumentException
{
public:
  NumberFormatException ();
  NumberFormatException (::java::lang::String *);
private:
  static const jlong serialVersionUID = -2848938806368998894LL;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_NumberFormatException__ */
