// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_rmi_CORBA_Stub__
#define __javax_rmi_CORBA_Stub__

#pragma interface

#include <javax/rmi/CORBA/ObjectImpl.h>

extern "Java"
{
  namespace javax
  {
    namespace rmi
    {
      class ORB;
      namespace CORBA
      {
        class Stub;
        class StubDelegate;
      }
    }
  }
}

class javax::rmi::CORBA::Stub : public ::javax::rmi::CORBA::ObjectImpl
{
public:  // actually protected
  Stub ();
public:
  virtual jint hashCode ();
  virtual jboolean equals (::java::lang::Object *);
  virtual ::java::lang::String *toString ();
  virtual void connect (::javax::rmi::ORB *);
private:
  void readObject (::java::io::ObjectInputStream *);
  void writeObject (::java::io::ObjectOutputStream *);
  ::javax::rmi::CORBA::StubDelegate * __attribute__((aligned(__alignof__( ::javax::rmi::CORBA::ObjectImpl )))) delegate;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_rmi_CORBA_Stub__ */
