// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_plaf_metal_MetalLookAndFeel__
#define __javax_swing_plaf_metal_MetalLookAndFeel__

#pragma interface

#include <javax/swing/plaf/basic/BasicLookAndFeel.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      namespace plaf
      {
        namespace metal
        {
          class MetalLookAndFeel;
        }
      }
      class UIDefaults;
    }
  }
}

class javax::swing::plaf::metal::MetalLookAndFeel : public ::javax::swing::plaf::basic::BasicLookAndFeel
{
public:
  virtual jboolean isNativeLookAndFeel ();
  virtual jboolean isSupportedLookAndFeel ();
  virtual ::java::lang::String *getDescription ();
  virtual ::java::lang::String *getID ();
  virtual ::java::lang::String *getName ();
  MetalLookAndFeel ();
  virtual ::javax::swing::UIDefaults *getDefaults ();
public: // actually package-private
  ::javax::swing::UIDefaults * __attribute__((aligned(__alignof__( ::javax::swing::plaf::basic::BasicLookAndFeel )))) LAF_defaults;
public:

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_plaf_metal_MetalLookAndFeel__ */
