// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_util_jar_JarFile__
#define __java_util_jar_JarFile__

#pragma interface

#include <java/util/zip/ZipFile.h>

class java::util::jar::JarFile : public ::java::util::zip::ZipFile
{
public:
  JarFile (::java::lang::String *);
  JarFile (::java::lang::String *, jboolean);
  JarFile (::java::io::File *);
  JarFile (::java::io::File *, jboolean);
  JarFile (::java::io::File *, jboolean, jint);
private:
  void verify ();
  ::java::util::jar::Manifest *readManifest ();
public:
  virtual ::java::util::Enumeration *entries ();
  virtual ::java::util::zip::ZipEntry *getEntry (::java::lang::String *);
  virtual ::java::io::InputStream *getInputStream (::java::util::zip::ZipEntry *);
  virtual ::java::util::jar::JarEntry *getJarEntry (::java::lang::String *);
  virtual ::java::util::jar::Manifest *getManifest ();
  static ::java::lang::String *MANIFEST_NAME;
private:
  ::java::util::jar::Manifest * __attribute__((aligned(__alignof__( ::java::util::zip::ZipFile )))) manifest;
  jboolean verify__;
  jboolean manifestRead;

  friend class java_util_jar_JarFile$JarEnumeration;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_util_jar_JarFile__ */
