// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_provider_MD5__
#define __gnu_java_security_provider_MD5__

#pragma interface

#include <java/security/MessageDigest.h>
#include <gcj/array.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace provider
        {
          class MD5;
        }
      }
    }
  }
}

class gnu::java::security::provider::MD5 : public ::java::security::MessageDigest
{
public:
  MD5 ();
  virtual ::java::lang::Object *clone ();
private:
  MD5 (::gnu::java::security::provider::MD5 *);
public:
  virtual jint engineGetDigestLength ();
  virtual void engineReset ();
  virtual void engineUpdate (jbyte);
  virtual void engineUpdate (jbyteArray, jint, jint);
  virtual jbyteArray engineDigest ();
private:
  jint F (jint, jint, jint);
  jint G (jint, jint, jint);
  jint H (jint, jint, jint);
  jint I (jint, jint, jint);
  jint rotateLeft (jint, jint);
  jint FF (jint, jint, jint, jint, jint, jint, jint);
  jint GG (jint, jint, jint, jint, jint, jint, jint);
  jint HH (jint, jint, jint, jint, jint, jint, jint);
  jint II (jint, jint, jint, jint, jint, jint, jint);
  jint SWAP (jint);
  void munch ();
  jintArray __attribute__((aligned(__alignof__( ::java::security::MessageDigest ))))  W;
  jlong bytecount;
  jint A;
  jint B;
  jint C;
  jint D;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_provider_MD5__ */
