// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __gnu_java_security_provider_DSAKeyPairGenerator__
#define __gnu_java_security_provider_DSAKeyPairGenerator__

#pragma interface

#include <java/security/KeyPairGeneratorSpi.h>

extern "Java"
{
  namespace gnu
  {
    namespace java
    {
      namespace security
      {
        namespace provider
        {
          class DSAKeyPairGenerator;
        }
      }
    }
  }
  namespace java
  {
    namespace math
    {
      class BigInteger;
    }
    namespace security
    {
      class KeyPair;
      namespace interfaces
      {
        class DSAParams;
      }
      namespace spec
      {
        class AlgorithmParameterSpec;
      }
      class SecureRandom;
    }
  }
}

class gnu::java::security::provider::DSAKeyPairGenerator : public ::java::security::KeyPairGeneratorSpi
{
public: // actually package-private
  DSAKeyPairGenerator ();
public:
  virtual void initialize (jint, ::java::security::SecureRandom *);
  virtual void initialize (::java::security::spec::AlgorithmParameterSpec *, ::java::security::SecureRandom *);
  virtual void initialize (::java::security::interfaces::DSAParams *, ::java::security::SecureRandom *);
  virtual void initialize (jint, jboolean, ::java::security::SecureRandom *);
  virtual ::java::security::KeyPair *generateKeyPair ();
private:
  jboolean getDefaults ();
public: // actually package-private
  jint __attribute__((aligned(__alignof__( ::java::security::KeyPairGeneratorSpi ))))  keysize;
  ::java::security::SecureRandom *random;
private:
  ::java::math::BigInteger *q;
  ::java::math::BigInteger *p;
  ::java::math::BigInteger *g;
public:

  static ::java::lang::Class class$;
};

#endif /* __gnu_java_security_provider_DSAKeyPairGenerator__ */
