// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_awt_image_IndexColorModel__
#define __java_awt_image_IndexColorModel__

#pragma interface

#include <java/awt/image/ColorModel.h>
#include <gcj/array.h>

extern "Java"
{
  namespace java
  {
    namespace awt
    {
      namespace image
      {
        class IndexColorModel;
      }
    }
  }
}

class java::awt::image::IndexColorModel : public ::java::awt::image::ColorModel
{
public:
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jint);
  IndexColorModel (jint, jint, jbyteArray, jbyteArray, jbyteArray, jbyteArray);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean);
  IndexColorModel (jint, jint, jbyteArray, jint, jboolean, jint);
  jint getMapSize () { return map_size; }
  jint getTransparentPixel () { return trans; }
  void getReds (jbyteArray);
  void getGreens (jbyteArray);
  void getBlues (jbyteArray);
  void getAlphas (jbyteArray);
private:
  void getComponents (jbyteArray, jint);
public:
  jint getRed (jint);
  jint getGreen (jint);
  jint getBlue (jint);
  jint getAlpha (jint);
  jint getRGB (jint);
private:
  jint generateMask (jint);
  jint __attribute__((aligned(__alignof__( ::java::awt::image::ColorModel ))))  map_size;
  jboolean opaque;
  jint trans;
  jintArray rgb;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_awt_image_IndexColorModel__ */
