// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_lang_Float__
#define __java_lang_Float__

#pragma interface

#include <java/lang/Number.h>

class java::lang::Float : public ::java::lang::Number
{
public:
  Float (jfloat);
  Float (jdouble);
  Float (::java::lang::String *);
  static ::java::lang::String *toString (jfloat);
  static ::java::lang::Float *valueOf (::java::lang::String *);
  static jfloat parseFloat (::java::lang::String *);
  static jboolean isNaN (jfloat);
  static jboolean isInfinite (jfloat);
  jboolean isNaN ();
  jboolean isInfinite ();
  ::java::lang::String *toString ();
  jbyte byteValue ();
  jshort shortValue ();
  jint intValue ();
  jlong longValue ();
  jfloat floatValue () { return value; }
  jdouble doubleValue ();
  jint hashCode ();
  jboolean equals (::java::lang::Object *);
  static jint floatToIntBits (jfloat);
  static jint floatToRawIntBits (jfloat);
  static jfloat intBitsToFloat (jint);
  jint compareTo (::java::lang::Float *);
  jint compareTo (::java::lang::Object *);
  static jint compare (jfloat, jfloat);
private:
  static const jlong serialVersionUID = -2671257302660747028LL;
public:
  static const jfloat MAX_VALUE = 0x1.fffffep+127f;
  static const jfloat MIN_VALUE = 0x0.000002p-126f;
  static const jfloat NEGATIVE_INFINITY;
  static const jfloat POSITIVE_INFINITY;
  static const jfloat NaN;
  static ::java::lang::Class *TYPE;
private:
  jfloat __attribute__((aligned(__alignof__( ::java::lang::Number ))))  value;
public:

  static ::java::lang::Class class$;
};

#endif /* __java_lang_Float__ */
