// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __java_security_acl_Group__
#define __java_security_acl_Group__

#pragma interface

#include <java/lang/Object.h>

extern "Java"
{
  namespace java
  {
    namespace security
    {
      namespace acl
      {
        class Group;
      }
      class Principal;
    }
  }
}

class java::security::acl::Group : public ::java::lang::Object
{
public:
  virtual jboolean addMember (::java::security::Principal *) = 0;
  virtual jboolean removeMember (::java::security::Principal *) = 0;
  virtual jboolean isMember (::java::security::Principal *) = 0;
  virtual ::java::util::Enumeration *members () = 0;

  static ::java::lang::Class class$;
} __attribute__ ((java_interface));

#endif /* __java_security_acl_Group__ */
