// DO NOT EDIT THIS FILE - it is machine generated -*- c++ -*-

#ifndef __javax_swing_ToggleButtonModel__
#define __javax_swing_ToggleButtonModel__

#pragma interface

#include <javax/swing/DefaultButtonModel.h>

extern "Java"
{
  namespace javax
  {
    namespace swing
    {
      class ToggleButtonModel;
      class JComponent;
    }
  }
}

class javax::swing::ToggleButtonModel : public ::javax::swing::DefaultButtonModel
{
public: // actually package-private
  ToggleButtonModel (::javax::swing::JComponent *);
public:
  virtual void setPressed (jboolean);

  static ::java::lang::Class class$;
};

#endif /* __javax_swing_ToggleButtonModel__ */
